package com.os.ems.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.record.domain.EmsVibrationInstance;
import com.os.ems.record.service.IEmsVibrationInstanceService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 震动实时数据Controller
 * 
 * @author ZangCH
 * @date 2024-08-21
 */
@RestController
@RequestMapping("/ems/record/recordVibrateInstance")
public class EmsVibrationInstanceController extends BaseController
{
    @Autowired
    private IEmsVibrationInstanceService emsVibrationInstanceService;

    /**
     * 查询震动实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrateInstance:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsVibrationInstance emsVibrationInstance)
    {
        startPage();
        List<EmsVibrationInstance> list = emsVibrationInstanceService.selectEmsVibrationInstanceList(emsVibrationInstance);
        return getDataTable(list);
    }

    /**
     * 导出震动实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrateInstance:export')")
    @Log(title = "震动实时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsVibrationInstance emsVibrationInstance)
    {
        List<EmsVibrationInstance> list = emsVibrationInstanceService.selectEmsVibrationInstanceList(emsVibrationInstance);
        ExcelUtil<EmsVibrationInstance> util = new ExcelUtil<EmsVibrationInstance>(EmsVibrationInstance.class);
        util.exportExcel(response, list, "震动实时数据数据");
    }

    /**
     * 获取震动实时数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrateInstance:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(emsVibrationInstanceService.selectEmsVibrationInstanceByObjId(objId));
    }

    /**
     * 新增震动实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrateInstance:add')")
    @Log(title = "震动实时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsVibrationInstance emsVibrationInstance)
    {
        emsVibrationInstance.setCreateBy(getUsername());
        return toAjax(emsVibrationInstanceService.insertEmsVibrationInstance(emsVibrationInstance));
    }

    /**
     * 修改震动实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrateInstance:edit')")
    @Log(title = "震动实时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsVibrationInstance emsVibrationInstance)
    {
        emsVibrationInstance.setUpdateBy(getUsername());
        return toAjax(emsVibrationInstanceService.updateEmsVibrationInstance(emsVibrationInstance));
    }

    /**
     * 删除震动实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordVibrateInstance:remove')")
    @Log(title = "震动实时数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(emsVibrationInstanceService.deleteEmsVibrationInstanceByObjIds(objIds));
    }
}
