package com.os.ems.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.record.domain.TWTempertureData;
import com.os.ems.record.service.ITWTempertureDataService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 物联网实时数据Controller
 * 
 * @author Caoql
 * @date 2024-08-21
 */
@RestController
@RequestMapping("/ems/record/recordIOTInstant")
public class TWTempertureDataController extends BaseController
{
    @Autowired
    private ITWTempertureDataService tWTempertureDataService;

    /**
     * 查询物联网实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIOTInstant:list')")
    @GetMapping("/list")
    public TableDataInfo list(TWTempertureData tWTempertureData)
    {
        startPage();
        List<TWTempertureData> list = tWTempertureDataService.selectTWTempertureDataList(tWTempertureData);
        return getDataTable(list);
    }

    /**
     * 导出物联网实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIOTInstant:export')")
    @Log(title = "物联网实时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TWTempertureData tWTempertureData)
    {
        List<TWTempertureData> list = tWTempertureDataService.selectTWTempertureDataList(tWTempertureData);
        ExcelUtil<TWTempertureData> util = new ExcelUtil<TWTempertureData>(TWTempertureData.class);
        util.exportExcel(response, list, "物联网实时数据数据");
    }

    /**
     * 获取物联网实时数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIOTInstant:query')")
    @GetMapping(value = "/{objid}")
    public AjaxResult getInfo(@PathVariable("objid") Long objid)
    {
        return success(tWTempertureDataService.selectTWTempertureDataByObjid(objid));
    }

    /**
     * 新增物联网实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIOTInstant:add')")
    @Log(title = "物联网实时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TWTempertureData tWTempertureData)
    {
        tWTempertureData.setCreateBy(getUsername());
        return toAjax(tWTempertureDataService.insertTWTempertureData(tWTempertureData));
    }

    /**
     * 修改物联网实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIOTInstant:edit')")
    @Log(title = "物联网实时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TWTempertureData tWTempertureData)
    {
        tWTempertureData.setUpdateBy(getUsername());
        return toAjax(tWTempertureDataService.updateTWTempertureData(tWTempertureData));
    }

    /**
     * 删除物联网实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIOTInstant:remove')")
    @Log(title = "物联网实时数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objids}")
    public AjaxResult remove(@PathVariable Long[] objids)
    {
        return toAjax(tWTempertureDataService.deleteTWTempertureDataByObjids(objids));
    }
}
