package com.os.mes.api.controller;

import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.mes.api.domain.ERPParamDto;
import com.os.mes.api.service.IERPPortService;
import com.os.mes.record.domain.RecordStaffSalary;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * ERP接口Controller
 *
 * @author Yinq
 * @date 2024-05-10
 */
@RestController
@RequestMapping("/erp")
public class ERPPortController extends BaseController {

    @Autowired
    private IERPPortService portService;

    /**
     * 获取ERP订单接口
     *
     * @param paramMap
     * @return
     */
    @PostMapping("/getERPOrderData")
    public AjaxResult getERPOrderData(@RequestBody Map paramMap) {
        ERPParamDto paramDto = new ERPParamDto();
        paramDto.setAppCode(String.valueOf(paramMap.get("AppCode")));
        paramDto.setController(String.valueOf(paramMap.get("Controller")));
        paramDto.setActionName(String.valueOf(paramMap.get("ActionName")));
        paramDto.setOrderStartTime(String.valueOf(paramMap.get("OrderStartTime")));
        paramDto.setOrderEndTime(String.valueOf(paramMap.get("OrderEndTime")));
        return AjaxResult.success(portService.getERPOrderData(paramDto));
    }

    /**
     * 获取员工工资系数
     *
     * @param paramMap
     * @return
     */
    @PostMapping("/getERPEmployeeWageData")
    public AjaxResult getERPEmployeeWageData(@RequestBody Map paramMap) {
        ERPParamDto paramDto = new ERPParamDto();
        paramDto.setAppCode(String.valueOf(paramMap.get("AppCode")));
        paramDto.setController(String.valueOf(paramMap.get("Controller")));
        paramDto.setActionName(String.valueOf(paramMap.get("ActionName")));
        return AjaxResult.success(portService.getERPEmployeeWageData(paramDto));
    }

    /**
     * 获取【政策与条款】-最新工资系数
     *
     * @param paramMap
     * @return
     */
    @PostMapping("/getERPLatestSalaryData")
    public AjaxResult getERPLatestSalaryData(@RequestBody Map paramMap) {
        ERPParamDto paramDto = new ERPParamDto();
        paramDto.setAppCode(String.valueOf(paramMap.get("AppCode")));
        paramDto.setController(String.valueOf(paramMap.get("Controller")));
        paramDto.setActionName(String.valueOf(paramMap.get("ActionName")));
        return AjaxResult.success(portService.getERPLatestSalaryData(paramDto));
    }

    /**
     * 新增【薪资明细】
     * @param recordStaffSalary
     * @return
     */
    @PostMapping("/addSalaryBreakdown")
    public AjaxResult addSalaryBreakdown(@RequestBody RecordStaffSalary recordStaffSalary) {
        return AjaxResult.success(portService.addSalaryBreakdown(recordStaffSalary));
    }


}
