package com.os.mes.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.base.domain.BaseFactory;
import com.os.mes.base.service.IBaseFactoryService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 工厂管理Controller
 * 
 * @author Yinq
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/mes/base/baseFactory")
public class BaseFactoryController extends BaseController
{
    @Autowired
    private IBaseFactoryService baseFactoryService;

    /**
     * 查询工厂管理列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseFactory:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseFactory baseFactory)
    {
        startPage();
        List<BaseFactory> list = baseFactoryService.selectBaseFactoryList(baseFactory);
        return getDataTable(list);
    }

    /**
     * 查询工厂下拉框列表
     */
    @GetMapping("/getBaseFactoryList")
    public AjaxResult getBaseFactoryList(BaseFactory baseFactory)
    {
        List<BaseFactory> list = baseFactoryService.selectBaseFactoryList(baseFactory);
        return success(list);
    }

    /**
     * 导出工厂管理列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseFactory:export')")
    @Log(title = "工厂管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseFactory baseFactory)
    {
        List<BaseFactory> list = baseFactoryService.selectBaseFactoryList(baseFactory);
        ExcelUtil<BaseFactory> util = new ExcelUtil<BaseFactory>(BaseFactory.class);
        util.exportExcel(response, list, "工厂管理数据");
    }

    /**
     * 获取工厂管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseFactory:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(baseFactoryService.selectBaseFactoryByObjId(objId));
    }

    /**
     * 新增工厂管理
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseFactory:add')")
    @Log(title = "工厂管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseFactory baseFactory)
    {
        baseFactory.setCreateBy(getUsername());
        return toAjax(baseFactoryService.insertBaseFactory(baseFactory));
    }

    /**
     * 修改工厂管理
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseFactory:edit')")
    @Log(title = "工厂管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseFactory baseFactory)
    {
        baseFactory.setUpdateBy(getUsername());
        return toAjax(baseFactoryService.updateBaseFactory(baseFactory));
    }

    /**
     * 删除工厂管理
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseFactory:remove')")
    @Log(title = "工厂管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(baseFactoryService.deleteBaseFactoryByObjIds(objIds));
    }
}
