package com.os.mes.prod.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.prod.domain.ProdBomInfo;
import com.os.mes.prod.service.IProdBomInfoService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 生产BOMController
 *
 * @author Yinq
 * @date 2024-05-11
 */
@RestController
@RequestMapping("/mes/prod/prodBomInfo")
public class ProdBomInfoController extends BaseController {
    @Autowired
    private IProdBomInfoService prodBomInfoService;

    /**
     * 查询生产BOM列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodBomInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdBomInfo prodBomInfo) {
        startPage();
        List<ProdBomInfo> list = prodBomInfoService.selectProdBomInfoList(prodBomInfo);
        return getDataTable(list);
    }

    /**
     * 查询生产BOM树列表
     */
    @GetMapping("/productionBomTreeList")
    public AjaxResult productionBomTreeList(ProdBomInfo prodBomInfo) {
        List<ProdBomInfo> list = prodBomInfoService.selectProductionBomTreeList(prodBomInfo);
        return success(list);
    }

    /**
     * 查询生产BOM列表
     */
    @GetMapping("/findOrderBomList")
    public AjaxResult findOrderBomList(ProdBomInfo prodBomInfo) {
        List<ProdBomInfo> list = prodBomInfoService.selectProdBomInfoList(prodBomInfo);
        return success(list);
    }

    /**
     * 导出生产BOM列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodBomInfo:export')")
    @Log(title = "生产BOM", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdBomInfo prodBomInfo) {
        List<ProdBomInfo> list = prodBomInfoService.selectProdBomInfoList(prodBomInfo);
        ExcelUtil<ProdBomInfo> util = new ExcelUtil<ProdBomInfo>(ProdBomInfo.class);
        util.exportExcel(response, list, "生产BOM数据");
    }

    /**
     * 获取生产BOM详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodBomInfo:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodBomInfoService.selectProdBomInfoByObjId(objId));
    }

    /**
     * 新增生产BOM
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodBomInfo:add')")
    @Log(title = "生产BOM", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdBomInfo prodBomInfo) {
        prodBomInfo.setCreateBy(getUsername());
        return toAjax(prodBomInfoService.insertProdBomInfo(prodBomInfo));
    }

    /**
     * 修改生产BOM
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodBomInfo:edit')")
    @Log(title = "生产BOM", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdBomInfo prodBomInfo) {
        prodBomInfo.setUpdateBy(getUsername());
        return toAjax(prodBomInfoService.updateProdBomInfo(prodBomInfo));
    }

    /**
     * 删除生产BOM
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodBomInfo:remove')")
    @Log(title = "生产BOM", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodBomInfoService.deleteProdBomInfoByObjIds(objIds));
    }

    /**
     * 通过生产BOM生成工单
     */
    @GetMapping("/generateTickets")
    public AjaxResult generateTickets(ProdBomInfo prodBomInfo) {
        List<ProdBomInfo> list = prodBomInfoService.generateTickets(prodBomInfo);
        return success(list);
    }
}
