package com.os.mes.prod.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.prod.domain.ProdPlanInfo;
import com.os.mes.prod.service.IProdPlanInfoService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 生产工单Controller
 *
 * @author Yinq
 * @date 2024-06-03
 */
@RestController
@RequestMapping("/mes/prod/prodPlanInfo")
public class ProdPlanInfoController extends BaseController {
    @Autowired
    private IProdPlanInfoService prodPlanInfoService;

    /**
     * 查询生产工单列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdPlanInfo prodPlanInfo) {
        startPage();
        List<ProdPlanInfo> list = prodPlanInfoService.selectProdPlanInfoList(prodPlanInfo);
        return getDataTable(list);
    }

    /**
     * 导出生产工单列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanInfo:export')")
    @Log(title = "生产工单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdPlanInfo prodPlanInfo) {
        List<ProdPlanInfo> list = prodPlanInfoService.selectProdPlanInfoList(prodPlanInfo);
        ExcelUtil<ProdPlanInfo> util = new ExcelUtil<ProdPlanInfo>(ProdPlanInfo.class);
        util.exportExcel(response, list, "生产工单数据");
    }

    /**
     * 获取生产工单详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanInfo:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodPlanInfoService.selectProdPlanInfoByObjId(objId));
    }

    /**
     * 新增生产工单
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanInfo:add')")
    @Log(title = "生产工单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdPlanInfo prodPlanInfo) {
        prodPlanInfo.setCreateBy(getUsername());
        return toAjax(prodPlanInfoService.insertProdPlanInfo(prodPlanInfo));
    }

    /**
     * 修改生产工单
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanInfo:edit')")
    @Log(title = "生产工单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdPlanInfo prodPlanInfo) {
        prodPlanInfo.setUpdateBy(getUsername());
        return toAjax(prodPlanInfoService.updateProdPlanInfo(prodPlanInfo));
    }

    /**
     * 删除生产工单
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanInfo:remove')")
    @Log(title = "生产工单", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodPlanInfoService.deleteProdPlanInfoByObjIds(objIds));
    }

    /**
     * 订单新增生产工单List
     * @param prodPlanInfos
     * @return
     */
    @PostMapping("/orderAddProdPlanInfoList")
    public AjaxResult orderAddProdPlanInfoList(@RequestBody List<ProdPlanInfo> prodPlanInfos) {
        return toAjax(prodPlanInfoService.orderAddProdPlanInfoList(prodPlanInfos));
    }

}
