package com.os.mes.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.record.domain.RecordStaffSalary;
import com.os.mes.record.service.IRecordStaffSalaryService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 员工工资记录Controller
 *
 * @author Yinq
 * @date 2024-07-02
 */
@RestController
@RequestMapping("/mes/record/recordStaffSalary")
public class RecordStaffSalaryController extends BaseController {
    @Autowired
    private IRecordStaffSalaryService recordStaffSalaryService;

    /**
     * 查询员工工资记录列表
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffSalary:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecordStaffSalary recordStaffSalary) {
        startPage();
        List<RecordStaffSalary> list = recordStaffSalaryService.selectRecordStaffSalaryList(recordStaffSalary);
        return getDataTable(list);
    }

    /**
     * 导出员工工资记录列表
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffSalary:export')")
    @Log(title = "员工工资记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordStaffSalary recordStaffSalary) {
        List<RecordStaffSalary> list = recordStaffSalaryService.selectRecordStaffSalaryList(recordStaffSalary);
        ExcelUtil<RecordStaffSalary> util = new ExcelUtil<RecordStaffSalary>(RecordStaffSalary.class);
        util.exportExcel(response, list, "员工工资记录数据");
    }

    /**
     * 获取员工工资记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffSalary:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(recordStaffSalaryService.selectRecordStaffSalaryByObjId(objId));
    }

    /**
     * 新增员工工资记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffSalary:add')")
    @Log(title = "员工工资记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordStaffSalary recordStaffSalary) {
        recordStaffSalary.setCreateBy(getUsername());
        return toAjax(recordStaffSalaryService.insertRecordStaffSalary(recordStaffSalary));
    }

    /**
     * 修改员工工资记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffSalary:edit')")
    @Log(title = "员工工资记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordStaffSalary recordStaffSalary) {
        recordStaffSalary.setUpdateBy(getUsername());
        return toAjax(recordStaffSalaryService.updateRecordStaffSalary(recordStaffSalary));
    }

    /**
     * 删除员工工资记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffSalary:remove')")
    @Log(title = "员工工资记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordStaffSalaryService.deleteRecordStaffSalaryByObjIds(objIds));
    }


    /**
     * 生成班组员工工资
     * @param recordStaffSalary
     * @return
     */
    @GetMapping("/selectTeamEmployeesWages")
    public AjaxResult selectTeamEmployeesWages(RecordStaffSalary recordStaffSalary) {
        List<RecordStaffSalary> list = recordStaffSalaryService.selectTeamEmployeesWages(recordStaffSalary);
        return success(list);
    }

    /**
     * 维护员工工资记录
     * 上传ERP
     * @param recordStaffSalaryList
     * @return
     */
    @PostMapping("/uploadERPStaffSalary")
    public AjaxResult uploadERPStaffSalary(@RequestBody List<RecordStaffSalary> recordStaffSalaryList) {
        return toAjax(recordStaffSalaryService.uploadERPStaffSalary(recordStaffSalaryList));
    }

}
