package com.os.mes.record.service.impl;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;

import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import com.os.common.utils.uuid.PlanCodeUtils;
import com.os.mes.api.domain.ERPParamDto;
import com.os.mes.api.domain.LatestSalary;
import com.os.mes.api.service.IERPPortService;
import com.os.mes.base.domain.BaseProcessInfo;
import com.os.mes.base.domain.BaseStaffInfo;
import com.os.mes.base.domain.BaseTeamMembers;
import com.os.mes.base.mapper.BaseProcessInfoMapper;
import com.os.mes.base.mapper.BaseStaffInfoMapper;
import com.os.mes.base.mapper.BaseTeamMembersMapper;
import com.os.mes.prod.domain.ProdOrderInfo;
import com.os.mes.prod.domain.ProdPlanDetail;
import com.os.mes.prod.domain.ProdPlanInfo;
import com.os.mes.prod.mapper.ProdOrderInfoMapper;
import com.os.mes.prod.mapper.ProdPlanInfoMapper;
import com.os.mes.record.domain.RecordStaffCommute;
import com.os.mes.record.mapper.RecordStaffCommuteMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.record.mapper.RecordStaffSalaryMapper;
import com.os.mes.record.domain.RecordStaffSalary;
import com.os.mes.record.service.IRecordStaffSalaryService;

/**
 * 员工工资记录Service业务层处理
 *
 * @author Yinq
 * @date 2024-07-02
 */
@Service
public class RecordStaffSalaryServiceImpl implements IRecordStaffSalaryService {
    @Autowired
    private RecordStaffSalaryMapper recordStaffSalaryMapper;

    @Autowired
    private BaseTeamMembersMapper baseTeamMembersMapper;

    @Autowired
    private BaseStaffInfoMapper baseStaffInfoMapper;

    @Autowired
    private ProdOrderInfoMapper prodOrderInfoMapper;

    @Autowired
    private ProdPlanInfoMapper prodPlanInfoMapper;

    @Autowired
    private BaseProcessInfoMapper baseProcessInfoMapper;

    @Autowired
    private RecordStaffCommuteMapper recordStaffCommuteMapper;

    @Autowired
    private IERPPortService portService;

    /**
     * 查询员工工资记录
     *
     * @param objId 员工工资记录主键
     * @return 员工工资记录
     */
    @Override
    public RecordStaffSalary selectRecordStaffSalaryByObjId(Long objId) {
        return recordStaffSalaryMapper.selectRecordStaffSalaryByObjId(objId);
    }

    /**
     * 查询员工工资记录列表
     *
     * @param recordStaffSalary 员工工资记录
     * @return 员工工资记录
     */
    @Override
    public List<RecordStaffSalary> selectRecordStaffSalaryList(RecordStaffSalary recordStaffSalary) {
        return recordStaffSalaryMapper.selectRecordStaffSalaryList(recordStaffSalary);
    }

    /**
     * 新增员工工资记录
     *
     * @param recordStaffSalary 员工工资记录
     * @return 结果
     */
    @Override
    public int insertRecordStaffSalary(RecordStaffSalary recordStaffSalary) {
        recordStaffSalary.setCreateTime(DateUtils.getNowDate());
        return recordStaffSalaryMapper.insertRecordStaffSalary(recordStaffSalary);
    }

    /**
     * 修改员工工资记录
     *
     * @param recordStaffSalary 员工工资记录
     * @return 结果
     */
    @Override
    public int updateRecordStaffSalary(RecordStaffSalary recordStaffSalary) {
        return recordStaffSalaryMapper.updateRecordStaffSalary(recordStaffSalary);
    }

    /**
     * 批量删除员工工资记录
     *
     * @param objIds 需要删除的员工工资记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordStaffSalaryByObjIds(Long[] objIds) {
        return recordStaffSalaryMapper.deleteRecordStaffSalaryByObjIds(objIds);
    }

    /**
     * 删除员工工资记录信息
     *
     * @param objId 员工工资记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordStaffSalaryByObjId(Long objId) {
        return recordStaffSalaryMapper.deleteRecordStaffSalaryByObjId(objId);
    }

    /**
     * 生成班组员工工资
     *
     * @param recordStaffSalary
     * @return
     */
    @Override
    public List<RecordStaffSalary> selectTeamEmployeesWages(RecordStaffSalary recordStaffSalary) {
        List<RecordStaffSalary> result = new ArrayList<>();

        //调用最新工资系数接口
        LatestSalary salaryData = portService.getERPLatestSalaryData(new ERPParamDto());

        //遍历工序
        List<BaseProcessInfo> processInfoList = baseProcessInfoMapper.selectBaseProcessInfoList(new BaseProcessInfo());

        ProdPlanInfo planInfo = new ProdPlanInfo();
        Map<String, Object> params = recordStaffSalary.getParams();
        planInfo.setParams(params);

        Date beginOrderDate = null;
        Date endOrderDate = null;
        if (params.containsKey("beginOrderDate")) {
            beginOrderDate = DateUtils.parseDate(String.valueOf(params.get("beginOrderDate")));
        }
        if (params.containsKey("endOrderDate")) {
            endOrderDate = DateUtils.parseDate(String.valueOf(params.get("endOrderDate")));
        }

        long objId = 1L;
        String taskCode = PlanCodeUtils.getTaskCode();

        for (BaseProcessInfo processInfo : processInfoList) {
            String processCode = processInfo.getProcessCode();
            planInfo.setProcessCode(processCode);
            List<ProdPlanInfo> planInfoList = prodPlanInfoMapper.selectProdPlanAndDetailList(planInfo);
            if (planInfoList.size() == 0) {
                continue;
            }
            //遍历ERP生产工单
            for (ProdPlanInfo plan : planInfoList) {
                ProdOrderInfo orderInfo = new ProdOrderInfo();
                orderInfo.setOrderCode(plan.getOrderCode());
                List<ProdOrderInfo> orderInfoList = prodOrderInfoMapper.selectProdOrderInfoList(orderInfo);
                List<ProdPlanDetail> prodPlanDetailList = plan.getProdPlanDetailList();
                //遍历生产工单明细
                for (ProdPlanDetail prodPlanDetail : prodPlanDetailList) {
                    HashMap<String, Object> selectMap = new HashMap<>();
                    Date beginTime = prodPlanDetail.getBeginTime();
                    Calendar calendar = Calendar.getInstance();
                    calendar.setTime(beginTime);
                    calendar.add(Calendar.HOUR, -8);
                    Date adjustedTime = calendar.getTime();
                    selectMap.put("beginStartWorkTime", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, adjustedTime));
                    selectMap.put("endStartWorkTime", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, beginTime));
                    RecordStaffCommute staffCommute = new RecordStaffCommute();
                    staffCommute.setParams(selectMap);
                    staffCommute.setTeamCode(plan.getTeamCode());
                    List<RecordStaffCommute> staffCommuteList = recordStaffCommuteMapper.selectRecordStaffCommuteList(staffCommute);
                    BigDecimal totalWageCoefficient = staffCommuteList.stream().map(RecordStaffCommute::getWageCoefficient)
                            .filter(Objects::nonNull).reduce(BigDecimal.ZERO, BigDecimal::add);

                    for (RecordStaffCommute recordStaffCommute : staffCommuteList) {
                        //工序工资系数
                        BigDecimal coefficient = new BigDecimal(0);
                        //工序生产面积
                        BigDecimal totalArea = new BigDecimal(0);

                        //硫化工序 工序硫化的工资 = 硫化系数*硫化面积*（工资系数/参加该工序的所有人的工资系数的总和）
                        //硫化面积=硫化米数/客户要求总米数*硫化面积
                        if (processCode.equals("1002")) {
                            coefficient = salaryData.getVulcanizationCoefficient();
                            totalArea = orderInfoList.stream().map(ProdOrderInfo::getOrderDetail)
                                    .map(e -> prodPlanDetail.getCompleteAmount().divide(e.getBeltRequiredLength(), 6, RoundingMode.HALF_UP)
                                            .multiply(e.getSulfurizationArea()))
                                    .reduce(BigDecimal.ZERO, BigDecimal::add);
                        }
                        //成型工序
                        if (processCode.equals("1001")) {
                            coefficient = salaryData.getFormingCoefficient();
                            totalArea = orderInfoList.stream().map(ProdOrderInfo::getOrderDetail)
                                    .map(e -> e.getBeltRequiredLength().divide(e.getBeltRequiredLength(), 6, RoundingMode.HALF_UP)
                                            .multiply(e.getFormingArea()))
                                    .reduce(BigDecimal.ZERO, BigDecimal::add);
                        }

                        BigDecimal staffCoefficient = recordStaffCommute.getWageCoefficient().divide(totalWageCoefficient, 6, RoundingMode.HALF_UP);
                        BigDecimal revenueAmount = coefficient.multiply(totalArea).multiply(staffCoefficient);
                        revenueAmount = revenueAmount.setScale(2, RoundingMode.HALF_UP);

                        String staffId = recordStaffCommute.getStaffId();
                        String teamCode = recordStaffCommute.getTeamCode();
                        String teamName = recordStaffCommute.getTeamName();
                        RecordStaffSalary staffSalary = new RecordStaffSalary();
                        for (RecordStaffSalary staff : result) {
                            if (staff.getCardId().equals(staffId)
                                    && staff.getGroupId().equals(recordStaffCommute.getTeamCode())) {
                                staffSalary = staff;
                            }
                        }
                        if (StringUtils.isEmpty(staffSalary.getCardId())) {
                            staffSalary.setObjId(objId++);
                            staffSalary.setTaskCode(taskCode);
                            staffSalary.setIdCard(recordStaffCommute.getPassWord());
                            staffSalary.setGroupId(teamCode);
                            staffSalary.setEventDate(new Date());
                            staffSalary.setSalaryCategory("收入");
                            staffSalary.setRevenueClass("完成生产任务");
                            revenueAmount = revenueAmount.setScale(2, RoundingMode.HALF_UP);
                            staffSalary.setRevenueAmount(revenueAmount);
                            staffSalary.setSalaryCoefficient(recordStaffCommute.getWageCoefficient());
                            staffSalary.setStaffName(recordStaffCommute.getStaffName());
                            staffSalary.setCardId(staffId);
                            staffSalary.setTeamName(teamName);
                            staffSalary.setBeginDate(beginOrderDate);
                            staffSalary.setEndDate(endOrderDate);
                            result.add(staffSalary);
                        } else {
                            staffSalary.setRevenueAmount(staffSalary.getRevenueAmount().add(revenueAmount));
                            staffSalary.setGroupId(teamCode);
                            staffSalary.setTeamName(teamName);
                        }
                    }
                }
            }

        }
        return result;
    }

//    /**
//     * 生成班组员工工资
//     * @param recordStaffSalary
//     * @return
//     */
//    @Override
//    public List<RecordStaffSalary> selectTeamEmployeesWages(RecordStaffSalary recordStaffSalary) {
//        List<RecordStaffSalary> result = new ArrayList<>();
//        BaseTeamMembers members = new BaseTeamMembers();
//        members.setTeamCode(recordStaffSalary.getGroupId());
//        List<BaseTeamMembers> membersList = baseTeamMembersMapper.selectBaseTeamMembersList(members);
//        //调用最新工资系数接口
//        LatestSalary salaryData = portService.getERPLatestSalaryData(new ERPParamDto());
//
//        ProdOrderInfo orderInfo = new ProdOrderInfo();
//        Map<String, Object> params = recordStaffSalary.getParams();
//        Date beginOrderDate = null;
//        Date endOrderDate = null;
//        if (params.containsKey("beginOrderDate")){
//            beginOrderDate = DateUtils.parseDate(String.valueOf(params.get("beginOrderDate")));
//        }
//        if (params.containsKey("endOrderDate")){
//            endOrderDate = DateUtils.parseDate(String.valueOf(params.get("endOrderDate")));
//        }
//        orderInfo.setParams(params);
//        List<ProdOrderInfo> orderInfoList = prodOrderInfoMapper.selectProdOrderInfoList(orderInfo);
//
//        long objId = 1L;
//        String taskCode = PlanCodeUtils.getTaskCode();
//        //按照班组 分工资；
//        for (BaseTeamMembers team : membersList) {
//            String processCode = team.getProcessCode();
//            //工序工资系数
//            BigDecimal coefficient = new BigDecimal(0);
//            //工序生产面积
//            BigDecimal totalArea = new BigDecimal(0);
//
//            //硫化工序 工序硫化的工资 = 硫化系数*硫化面积*（工资系数/参加该工序的所有人的工资系数的总和）
//            //硫化面积=硫化米数/客户要求总米数*硫化面积
//            if(processCode.equals("1002")){
//                coefficient = salaryData.getVulcanizationCoefficient();
//                totalArea = orderInfoList.stream().map(ProdOrderInfo::getOrderDetail)
//                        .map(e -> e.getBeltRequiredLength().divide(e.getBeltRequiredLength(), 6, RoundingMode.HALF_UP)
//                                .multiply(e.getSulfurizationArea()))
//                        .reduce(BigDecimal.ZERO, BigDecimal::add);
//            }
//            //成型工序
//            if(processCode.equals("1001")){
//                coefficient = salaryData.getFormingCoefficient();
//                totalArea = orderInfoList.stream().map(ProdOrderInfo::getOrderDetail)
//                        .map(e -> e.getBeltRequiredLength().divide(e.getBeltRequiredLength(), 6, RoundingMode.HALF_UP)
//                                .multiply(e.getFormingArea()))
//                        .reduce(BigDecimal.ZERO, BigDecimal::add);
//            }
//            //获取这个时间段内员工打卡记录
//            BaseStaffInfo selectStaffInfo = new BaseStaffInfo();
//            selectStaffInfo.setTeamCode(team.getTeamCode());
//            selectStaffInfo.setDelFlag("0");
//            List<BaseStaffInfo> staffInfoList = baseStaffInfoMapper.selectBaseStaffInfoList(selectStaffInfo);
//            BigDecimal totalWageCoefficient = staffInfoList.stream().map(BaseStaffInfo::getWageCoefficient)
//                    .filter(Objects::nonNull).reduce(BigDecimal.ZERO, BigDecimal::add);
//
//            for (BaseStaffInfo staffInfo : staffInfoList) {
//                RecordStaffSalary staffSalary = new RecordStaffSalary();
//                staffSalary.setObjId(objId++);
//                staffSalary.setTaskCode(taskCode);
//                staffSalary.setIdCard(staffInfo.getPassWord());
//                staffSalary.setGroupId(team.getTeamCode());
//                staffSalary.setEventDate(new Date());
//                staffSalary.setSalaryCategory("收入");
//                staffSalary.setRevenueClass("完成生产任务");
//                BigDecimal staffCoefficient = staffInfo.getWageCoefficient().divide(totalWageCoefficient, 6, RoundingMode.HALF_UP);
//                BigDecimal revenueAmount = coefficient.multiply(totalArea).multiply(staffCoefficient);
//                revenueAmount = revenueAmount.setScale(2, RoundingMode.HALF_UP);
//                staffSalary.setRevenueAmount(revenueAmount);
//                staffSalary.setSalaryCoefficient(staffInfo.getWageCoefficient());
//                staffSalary.setStaffName(staffInfo.getStaffName());
//                staffSalary.setCardId(staffInfo.getCardId());
//                staffSalary.setTeamName(team.getTeamName());
//                staffSalary.setBeginDate(beginOrderDate);
//                staffSalary.setEndDate(endOrderDate);
//                result.add(staffSalary);
//            }
//
//        }
//        return result;
//    }

    /**
     * 维护员工工资记录
     * 上传ERP
     *
     * @param recordStaffSalaryList
     * @return
     */
    @Override
    public int uploadERPStaffSalary(List<RecordStaffSalary> recordStaffSalaryList) {
        Thread thread = new Thread(() -> {
            for (RecordStaffSalary staffSalary : recordStaffSalaryList) {
                String objectId = portService.addSalaryBreakdown(staffSalary);
                staffSalary.setObjectId(objectId);
                recordStaffSalaryMapper.insertRecordStaffSalary(staffSalary);
            }
        });
        thread.start(); //启动新线程

        return 1;
    }

}
