package com.os.quartz.task;


import com.os.mes.api.domain.ERPParamDto;
import com.os.mes.api.service.IERPPortService;
import com.os.mes.api.utils.ERPConstants;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;


/**
 * @Author YinQ
 * @create 2023-10-08 9:11
 */
@Component("ERPTask")
public class ERPTask {

    @Autowired
    private IERPPortService portService;

    public void ERPOrderTask(Long startDays, Long endDays) {
        String startDate = convertDaysToDateString(startDays, 0);
        String endDate = convertDaysToDateString(endDays, 1);
        ERPParamDto paramDto = new ERPParamDto();
        paramDto.setAppCode(ERPConstants.orderAppCode);
        paramDto.setController(ERPConstants.orderController);
        paramDto.setActionName(ERPConstants.orderActionName);
        paramDto.setOrderStartTime(startDate);
        paramDto.setOrderEndTime(endDate);
        portService.getERPOrderData(paramDto);
    }

    public void ERPEmployeeWageTask() {
        ERPParamDto paramDto = new ERPParamDto();
        paramDto.setAppCode(ERPConstants.employeeAppCode);
        paramDto.setController(ERPConstants.employeeController);
        paramDto.setActionName(ERPConstants.employeeActionName);
        portService.getERPEmployeeWageData(paramDto);
    }

    public void ERPLatestSalaryTask() {
        ERPParamDto paramDto = new ERPParamDto();
        paramDto.setAppCode(ERPConstants.salaryAppCode);
        paramDto.setController(ERPConstants.salaryController);
        paramDto.setActionName(ERPConstants.salaryActionName);
        portService.getERPEmployeeWageData(paramDto);
    }

    /**
     * 输出days天type的日期
     * type: 0-减法；1-加法
     *
     * @param days
     * @return
     */
    public static String convertDaysToDateString(Long days, Integer type) {
        // 获取当前日期
        LocalDate currentDate = LocalDate.now();
        LocalDate targetDate = null;
        // 减去相应的天数
        if (type.equals(0)) {
            targetDate = currentDate.minusDays(days);
        } else {
            targetDate = currentDate.plusDays(days);
        }

        // 创建DateTimeFormatter对象，指定日期格式
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd 00:00:00");

        // 格式化日期为字符串并返回
        return targetDate.format(formatter);
    }
}
